==> calendar-v1.7.21.zip: calendar/messages/da/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Tilføj</strong> profilkalender',
    '<strong>Choose</strong> target calendar' => '<strong>Vælg</strong> målkalender',
    '<strong>Reminder</strong> settings' => 'Indstillinger for <strong>påmindelse</strong>.',
    'Add all Space members with status {status}' => 'Tilføj alle medlemmer af rum med status {status}',
    'Add participants...' => 'Tilføj deltagere...',
    'Added: {users}' => 'Tilføjet: {users}',
    'Additional Information for participants' => 'Yderligere information til deltagerne',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Tilføjer en kalender for private eller offentlige begivenheder til din profil og hovedmenu.',
    'Adds an event calendar to this space.' => 'Tilføjer en begivenhedskalender til dette rum.',
    'After (occurrences)' => 'Efter (occurrences)',
    'All Day' => 'Hele dagen',
    'Allow option \'Decline\'' => 'Tillad indstillingen \'Afvis\'',
    'Allow option \'Undecided\'' => 'Tillad valgmuligheden \'Ubeslutsom\'',
    'Allows the user to create new calendar entries' => 'Giver brugeren mulighed for at oprette nye kalenderposter',
    'Allows the user to edit/delete existing calendar entries' => 'Giver brugeren mulighed for at redigere/slette eksisterende kalenderposter',
    'Attending' => 'Deltager',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Før der kan vælges en målkalender, skal modulet være aktiveret i mindst ét rum.',
    'Birthday' => 'Fødselsdag',
    'Calendar' => 'Kalender',
    'Calendar event' => 'Kalenderbegivenhed',
    'Calendar events' => 'Kalenderbegivenheder',
    'Cancel Event' => 'Annullér begivenhed',
    'Cannot remove the participant!' => 'Kan ikke fjerne deltageren!',
    'Create entry' => 'Opret post',
    'Custom reminder' => 'Tilpasset påmindelse',
    'Day' => 'Dag',
    'Days' => 'Dage',
    'Default reminder settings' => 'Standardindstillinger for påmindelser',
    'Delete all events' => 'Slet alle begivenheder',
    'Deleted' => 'Slettet',
    'Description' => 'Beskrivelse',
    'Display events within the next X days' => 'Vis begivenheder inden for de næste X dage',
    'Do you want to install this module on your profile?' => 'Vil du installere dette modul på din profil?',
    'Download ICS' => 'Download ICS',
    'Edit' => 'Rediger',
    'Edit Event' => 'Rediger begivenhed',
    'Edit all events' => 'Rediger alle begivenheder',
    'Edit this and following events' => 'Rediger denne og følgende begivenheder',
    'Edit this event' => 'Rediger denne begivenhed',
    'Email' => 'E-mail',
    'Enable' => 'Aktivér',
    'Enable Reminder' => 'Aktivér påmindelse',
    'End' => 'Slut',
    'End Date' => 'Slutdato',
    'End Time' => 'Sluttidspunkt',
    'End time must be after start time!' => 'Sluttidspunktet skal være efter starttidspunktet!',
    'Event' => 'Begivenhed',
    'Event Type' => 'Begivenhedstype',
    'Event Types' => 'Begivenhedstyper',
    'Event could not be deleted!' => 'Begivenheden kunne ikke slettes!',
    'Event has been be deleted!' => 'Event has been be deleted!',
    'Event not found!' => 'Begivenhed ikke fundet!',
    'Export as {type}' => 'Eksporter som {type}',
    'Files' => 'Filer',
    'Filter by types' => 'Filtrer efter typer',
    'Friday' => 'Fredag',
    'From Newest to Oldest' => 'Fra nyeste til ældste',
    'From Oldest to Newest' => 'Fra ældste til nyeste',
    'Here you can configure default settings for all calendar events.' => 'Her kan du konfigurere standardindstillinger for alle kalenderbegivenheder.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Her kan du konfigurere globale standardpåmindelser. Disse indstillinger kan overskrives på rum-/profilniveau.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Her kan du konfigurere standardindstillingerne for påmindelser for denne begivenhed. Brugere kan overskrive disse indstillinger ved hjælp af <strong>Indstil påmindelse</strong> link.',
    'Hour' => 'Time',
    'I\'m attending' => 'Jeg deltager',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'For at kunne tilføje begivenheder til din profil skal du først aktivere kalendermodulet.',
    'Interested' => 'Interesseret',
    'Invalid date or time format!' => 'Ugyldigt dato- eller tidsformat!',
    'Invalid day of month given' => 'Ugyldig dag i måneden angivet',
    'Invalid event type id selected.' => 'Ugyldigt id for valgt begivenhedstype.',
    'Invalid frequency given' => 'Ugyldig frekvens angivet',
    'Invalid interval given' => 'Ugyldigt interval angivet',
    'Invalid week day selection' => 'Ugyldig valg af ugedag',
    'Invite' => 'Invitér',
    'Invited: {users}' => 'Inviteret: {users}',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => 'Lad det være tomt for at vise alle begivenheder. Indtast 0 for kun at vise dagens begivenheder.',
    'List' => 'Liste',
    'Location' => 'Sted',
    'Manage entries' => 'Administrer poster',
    'Maximum number of participants' => 'Maksimalt antal deltagere',
    'Minute' => 'Minut',
    'Mode' => 'Tilstand',
    'Monday' => 'Mandag',
    'Month' => 'Måned',
    'Monthly on day {dayOfMonth}' => 'Månedligt på dagen {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Månedligt på den {position} {dayOfWeek}',
    'Months' => 'Måneder',
    'Never' => 'Aldrig',
    'Next' => 'Næste',
    'No new participants were added.' => 'Ingen nye deltagere blev tilføjet.',
    'No new participants were invited.' => 'Ingen nye deltagere var inviteret.',
    'No reminder' => 'Ingen påmindelse',
    'Notify participants about changes' => 'Underret deltagere om ændringer',
    'On date' => 'På dato',
    'Participant removed.' => 'Deltager fjernet.',
    'Participants' => 'Deltagere',
    'Participation Status' => 'Deltagelsesstatus',
    'Please select new participants.' => 'Vælg venligst nye deltagere.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Private begivenheder er kun synlige for dig og, hvis venskabssystemet er aktiveret, for dine venner.',
    'Profile Calendar' => 'Profilkalender',
    'Public' => 'Offentlig',
    'Recurring' => 'Tilbagevendende',
    'Reopen Event' => 'Åbn begivenhed igen',
    'Repeat every' => 'Gentag hver',
    'Saturday' => 'Lørdag',
    'Select calendar...' => 'Vælg kalender...',
    'Select space...' => 'Vælg rum...',
    'Set reminder' => 'Indstil påmindelse',
    'Show past events' => 'Vis tidligere begivenheder',
    'Sorting' => 'Sortering',
    'Start Date' => 'Startdato',
    'Start Time' => 'Starttidspunkt',
    'Status cannot be updated.' => 'Status kan ikke opdateres.',
    'Status updated.' => 'Status opdateret.',
    'Sunday' => 'Søndag',
    'The event has already ended.' => 'Begivenheden er allerede slut.',
    'This event does not support recurrent events' => 'Denne begivenhed understøtter ikke tilbagevendende begivenheder',
    'Thursday' => 'Torsdag',
    'Time Zone' => 'Tidszone',
    'Title' => 'Titel',
    'Today' => 'I dag',
    'Tuesday' => 'Tirsdag',
    'Upcoming {type}' => 'Kommende {type}',
    'Upcoming {type}: {title}' => 'Kommende {type}: {title}',
    'Use default reminder' => 'Brug standardpåmindelse',
    'User birthdays' => 'Brugeres fødselsdage',
    'Wednesday' => 'Onsdag',
    'Week' => 'Uge',
    'Weeks' => 'Uger',
    'Year' => 'År',
    'Years' => 'År',
    'You cannot invite participants!' => 'Du kan ikke invitere deltagere!',
    'You don\'t have permission to delete this event!' => 'Du har ikke tilladelse til at slette denne begivenhed!',
    'You have an <strong>{type}</strong> coming up' => 'Du har en <strong>{type}</strong> på vej',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Du har en <strong>{type}</strong> på vej: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Du er blevet tilmeldt begivenheden "{contentTitle}" i {spaceName}, med start kl. {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Du er blevet tilmeldt begivenheden"{contentTitle}", med start kl. {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Du er blevet tilmeldt begivenheden" {contentTitle}".',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Dine påmindelsesindstillinger for begivenhed: <strong>\'{title}\'</strong>',
    'canceled' => 'aflyst',
    'disabled' => 'handicappede',
    'first' => 'første',
    'forth' => 'frem',
    'global' => 'globalt',
    'last' => 'sidste',
    'on weekdays' => 'på hverdage',
    'second' => 'anden',
    'third' => 'tredje',
    '{displayName} Birthday' => '{displayName} fødselsdag',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} føjede dig til begivenheden "{contentTitle}" i rummet {spaceName}, med start kl. {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} tilføjede dig til begivenheden "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} inviterede dig til begivenheden"{contentTitle}" i rummet {spaceName}, med start kl. {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} invited you to the event "{contentTitle}".',
    'CalDAV' => '',
    'Calendar event content ID' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{name} Calendar' => '',
];

==> calendar-v1.8.4.zip: calendar/messages/da/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Tilføj</strong> profilkalender',
    '<strong>Choose</strong> target calendar' => '<strong>Vælg</strong> målkalender',
    '<strong>Reminder</strong> settings' => 'Indstillinger for <strong>påmindelse</strong>.',
    'Add all Space members with status {status}' => 'Tilføj alle medlemmer af rum med status {status}',
    'Add participants...' => 'Tilføj deltagere...',
    'Added: {users}' => 'Tilføjet: {users}',
    'Additional Information for participants' => 'Yderligere information til deltagerne',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Tilføjer en kalender for private eller offentlige begivenheder til din profil og hovedmenu.',
    'Adds an event calendar to this space.' => 'Tilføjer en begivenhedskalender til dette rum.',
    'After (occurrences)' => 'Efter (occurrences)',
    'All Day' => 'Hele dagen',
    'Allow option \'Decline\'' => 'Tillad indstillingen \'Afvis\'',
    'Allow option \'Undecided\'' => 'Tillad valgmuligheden \'Ubeslutsom\'',
    'Allows the user to create new calendar entries' => 'Giver brugeren mulighed for at oprette nye kalenderposter',
    'Allows the user to edit/delete existing calendar entries' => 'Giver brugeren mulighed for at redigere/slette eksisterende kalenderposter',
    'Attending' => 'Deltager',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Før der kan vælges en målkalender, skal modulet være aktiveret i mindst ét rum.',
    'Birthday' => 'Fødselsdag',
    'CalDAV' => 'CalDAV',
    'Calendar' => 'Kalender',
    'Calendar event' => 'Kalenderbegivenhed',
    'Calendar event content ID' => 'ID for indhold i kalenderbegivenhed',
    'Calendar events' => 'Kalenderbegivenheder',
    'Cancel Event' => 'Annullér begivenhed',
    'Cannot remove the participant!' => 'Kan ikke fjerne deltageren!',
    'Create entry' => 'Opret post',
    'Custom reminder' => 'Tilpasset påmindelse',
    'Day' => 'Dag',
    'Days' => 'Dage',
    'Default reminder settings' => 'Standardindstillinger for påmindelser',
    'Delete all events' => 'Slet alle begivenheder',
    'Deleted' => 'Slettet',
    'Description' => 'Beskrivelse',
    'Display events within the next X days' => 'Vis begivenheder inden for de næste X dage',
    'Do you want to install this module on your profile?' => 'Vil du installere dette modul på din profil?',
    'Download ICS' => 'Download ICS',
    'Edit' => 'Rediger',
    'Edit Event' => 'Rediger begivenhed',
    'Edit all events' => 'Rediger alle begivenheder',
    'Edit this and following events' => 'Rediger denne og følgende begivenheder',
    'Edit this event' => 'Rediger denne begivenhed',
    'Email' => 'E-mail',
    'Enable' => 'Aktivér',
    'Enable Reminder' => 'Aktivér påmindelse',
    'End' => 'Slut',
    'End Date' => 'Slutdato',
    'End Time' => 'Sluttidspunkt',
    'End time must be after start time!' => 'Sluttidspunktet skal være efter starttidspunktet!',
    'Event' => 'Begivenhed',
    'Event Type' => 'Begivenhedstype',
    'Event Types' => 'Begivenhedstyper',
    'Event could not be deleted!' => 'Begivenheden kunne ikke slettes!',
    'Event has been be deleted!' => 'Event has been be deleted!',
    'Event not found!' => 'Begivenhed ikke fundet!',
    'Export as {type}' => 'Eksporter som {type}',
    'Files' => 'Filer',
    'Filter by types' => 'Filtrer efter typer',
    'Friday' => 'Fredag',
    'From Newest to Oldest' => 'Fra nyeste til ældste',
    'From Oldest to Newest' => 'Fra ældste til nyeste',
    'Here you can configure default settings for all calendar events.' => 'Her kan du konfigurere standardindstillinger for alle kalenderbegivenheder.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Her kan du konfigurere globale standardpåmindelser. Disse indstillinger kan overskrives på rum-/profilniveau.',
    'Hour' => 'Time',
    'I\'m attending' => 'Jeg deltager',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'For at kunne tilføje begivenheder til din profil skal du først aktivere kalendermodulet.',
    'Include Organizer and Participant Info in Exports' => 'Inkluder arrangør- og deltagerinformation i eksport',
    'Interested' => 'Interesseret',
    'Invalid date or time format!' => 'Ugyldigt dato- eller tidsformat!',
    'Invalid day of month given' => 'Ugyldig dag i måneden angivet',
    'Invalid event type id selected.' => 'Ugyldigt id for valgt begivenhedstype.',
    'Invalid frequency given' => 'Ugyldig frekvens angivet',
    'Invalid interval given' => 'Ugyldigt interval angivet',
    'Invalid week day selection' => 'Ugyldig valg af ugedag',
    'Invite' => 'Invitér',
    'Invited: {users}' => 'Inviteret: {users}',
    'JWT Key' => 'JWT-nøgle',
    'JWT Token Expiration' => 'Udløb af JWT-token',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => 'Lad det være tomt for at vise alle begivenheder. Indtast 0 for kun at vise dagens begivenheder.',
    'List' => 'Liste',
    'Location' => 'Sted',
    'Manage entries' => 'Administrer poster',
    'Maximum number of participants' => 'Maksimalt antal deltagere',
    'Minute' => 'Minut',
    'Mode' => 'Tilstand',
    'Monday' => 'Mandag',
    'Month' => 'Måned',
    'Monthly on day {dayOfMonth}' => 'Månedligt på dagen {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Månedligt på den {position} {dayOfWeek}',
    'Months' => 'Måneder',
    'Never' => 'Aldrig',
    'Next' => 'Næste',
    'No new participants were added.' => 'Ingen nye deltagere blev tilføjet.',
    'No new participants were invited.' => 'Ingen nye deltagere var inviteret.',
    'No reminder' => 'Ingen påmindelse',
    'Notify participants about changes' => 'Underret deltagere om ændringer',
    'On date' => 'På dato',
    'Participant removed.' => 'Deltager fjernet.',
    'Participants' => 'Deltagere',
    'Participation Status' => 'Deltagelsesstatus',
    'Please select new participants.' => 'Vælg venligst nye deltagere.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Private begivenheder er kun synlige for dig og, hvis venskabssystemet er aktiveret, for dine venner.',
    'Profile Calendar' => 'Profilkalender',
    'Public' => 'Offentlig',
    'Recurring' => 'Tilbagevendende',
    'Reopen Event' => 'Åbn begivenhed igen',
    'Repeat every' => 'Gentag hver',
    'Saturday' => 'Lørdag',
    'Select calendar...' => 'Vælg kalender...',
    'Select space...' => 'Vælg rum...',
    'Set reminder' => 'Indstil påmindelse',
    'Show past events' => 'Vis tidligere begivenheder',
    'Sorting' => 'Sortering',
    'Start Date' => 'Startdato',
    'Start Time' => 'Starttidspunkt',
    'Status cannot be updated.' => 'Status kan ikke opdateres.',
    'Status updated.' => 'Status opdateret.',
    'Sunday' => 'Søndag',
    'The event has already ended.' => 'Begivenheden er allerede slut.',
    'This event does not support recurrent events' => 'Denne begivenhed understøtter ikke tilbagevendende begivenheder',
    'Thursday' => 'Torsdag',
    'Time Zone' => 'Tidszone',
    'Title' => 'Titel',
    'Today' => 'I dag',
    'Tuesday' => 'Tirsdag',
    'Upcoming {type}' => 'Kommende {type}',
    'Upcoming {type}: {title}' => 'Kommende {type}: {title}',
    'Use default reminder' => 'Brug standardpåmindelse',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => 'Bruges til sikker generering af iCal-feed-URL\'er og CalDAV-godkendelse. Hvis du ændrer denne nøgle, tilbagekaldes alle eksisterende iCal-URL\'er og CalDAV-logins. Hvis den er tom, genereres der automatisk en tilfældig nøgle.',
    'User birthdays' => 'Brugeres fødselsdage',
    'Wednesday' => 'Onsdag',
    'Week' => 'Uge',
    'Weeks' => 'Uger',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => 'Når den er aktiveret, vil kalendereksport (ics, iCal, CalDAV) inkludere arrangørens og deltagerens navne og e-mailadresser. Deaktiver for at udelukke disse oplysninger for at øge privatlivets fred.',
    'Year' => 'År',
    'Years' => 'År',
    'You cannot invite participants!' => 'Du kan ikke invitere deltagere!',
    'You don\'t have permission to delete this event!' => 'Du har ikke tilladelse til at slette denne begivenhed!',
    'You have an <strong>{type}</strong> coming up' => 'Du har en <strong>{type}</strong> på vej',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Du har en <strong>{type}</strong> på vej: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Du er blevet tilmeldt begivenheden "{contentTitle}" i {spaceName}, med start kl. {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Du er blevet tilmeldt begivenheden"{contentTitle}", med start kl. {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Du er blevet tilmeldt begivenheden" {contentTitle}".',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Dine påmindelsesindstillinger for begivenhed: <strong>\'{title}\'</strong>',
    'canceled' => 'aflyst',
    'disabled' => 'handicappede',
    'first' => 'første',
    'forth' => 'frem',
    'global' => 'globalt',
    'iCal' => 'iCal',
    'in seconds. 0 for no JWT token expiration.' => 'i sekunder. 0 for ingen udløb af JWT-token.',
    'last' => 'sidste',
    'on weekdays' => 'på hverdage',
    'second' => 'anden',
    'third' => 'tredje',
    '{displayName} Birthday' => '{displayName} fødselsdag',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} føjede dig til begivenheden "{contentTitle}" i rummet {spaceName}, med start kl. {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} tilføjede dig til begivenheden "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} inviterede dig til begivenheden"{contentTitle}" i rummet {spaceName}, med start kl. {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} invited you to the event "{contentTitle}".',
    '{name} Calendar' => '{name} Kalender',
    'Filter' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
];
